@@ -36,22 +36,16 @@ class XMLReader(FileHandler):
             else:
                 return self.__parse_xml_root(xml_objs, handler, buffer)
 
-    @staticmethod
-    def __parse_xml_root(xml_objs, handler=None, buffer=None):
+    def __parse_xml_root(self, xml_objs, handler=None, buffer=None):
         xml_dicts = list()
         row_num = 0
-        header = None
 
         for xml_obj in xml_objs:
             xml_dicts.append(self.__parse_element(xml_obj))
 
-            if not header:
-                header = converted_row
-
             if handler and buffer <= len(xml_dicts):
                 handler(self.file_path, self.__parse_df(xml_dicts), row_num - len(xml_dicts) + 1, **self.kwargs)
                 xml_dicts.clear()
-                xml_dicts.append(header)
 
             row_num += 1
 
